CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
71 lines
2.6 KiB
C++
71 lines
2.6 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#if defined(__HIP_PLATFORM_AMD__) || CUDA_VERSION < CUDA_12000
|
|
texture<float, 2, hipReadModeElementType> tex;
|
|
|
|
// Test for hipTexRefSetMipmappedArray and hipTexRefGetMipmappedArray, including error handling
|
|
HIP_TEST_CASE(Unit_hipTexRefSetGetMipmappedArray) {
|
|
CHECK_IMAGE_SUPPORT;
|
|
|
|
// Retrieve the texture reference for our symbol
|
|
const textureReference* texRefConst = nullptr;
|
|
HIP_CHECK(hipGetTextureReference(&texRefConst, &tex));
|
|
REQUIRE(texRefConst != nullptr);
|
|
// Implementation expects non-const textureReference*
|
|
textureReference* texRef = const_cast<textureReference*>(texRefConst);
|
|
hipMipmappedArray_t mipArr = nullptr;
|
|
hipMipmappedArray_t outArr = nullptr;
|
|
unsigned int Flags = 0;
|
|
|
|
|
|
SECTION("Default mipmapped array GET returns invalid value when none bound") {
|
|
hipError_t err = hipTexRefGetMipMappedArray(&outArr, texRef);
|
|
REQUIRE(err == hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("Set and get mipmapped array") {
|
|
hipMipmappedArray_t mipmapped_array;
|
|
HIP_RESOURCE_DESC res_desc{};
|
|
hipModule_t module = nullptr;
|
|
hipExtent extent;
|
|
hipChannelFormatDesc channel_desc;
|
|
unsigned int width = 256, height = 256, mipmap_level = 2;
|
|
|
|
res_desc.resType = HIP_RESOURCE_TYPE_MIPMAPPED_ARRAY;
|
|
|
|
channel_desc = hipCreateChannelDesc<float>();
|
|
extent = make_hipExtent(width, height, 0);
|
|
auto res = hipMallocMipmappedArray(&mipmapped_array, &channel_desc, extent, 2 * mipmap_level,
|
|
hipArrayDefault);
|
|
if (res == hipErrorNotSupported) {
|
|
WARN("Skipping section: " << HipTest::SkipReason::kMipmappedArraysUnsupported);
|
|
return;
|
|
}
|
|
HIP_CHECK(res);
|
|
HIP_CHECK(hipFree(nullptr));
|
|
HIP_CHECK(hipModuleLoad(&module, "tex_ref_get_module.code"));
|
|
HIP_CHECK(hipModuleGetTexRef(&texRef, module, "tex"));
|
|
HIP_CHECK(hipTexRefSetFlags(texRef, HIP_TRSF_NORMALIZED_COORDINATES));
|
|
HIP_CHECK(hipTexRefSetMipmappedArray(texRef, mipmapped_array, HIP_TRSA_OVERRIDE_FORMAT));
|
|
HIP_CHECK(hipTexRefGetMipMappedArray(&outArr, texRef));
|
|
REQUIRE(outArr == mipmapped_array);
|
|
HIP_CHECK(hipFreeMipmappedArray(mipmapped_array));
|
|
}
|
|
|
|
SECTION("Invalid arguments: null pointers") {
|
|
hipError_t err;
|
|
err = hipTexRefSetMipmappedArray(nullptr, mipArr, Flags);
|
|
REQUIRE(err == hipErrorInvalidValue);
|
|
err = hipTexRefGetMipMappedArray(&outArr, nullptr);
|
|
REQUIRE(err == hipErrorInvalidValue);
|
|
err = hipTexRefGetMipMappedArray(nullptr, texRef);
|
|
REQUIRE(err == hipErrorInvalidValue);
|
|
}
|
|
}
|
|
#endif
|